@@ -3,8 +3,8 @@ from .dqn import *
 from .td import *
 
 __all__ = ['FQI', 'DoubleFQI', 'BoostedFQI', 'LSPI', 'AbstractDQN', 'DQN', 'DoubleDQN',
-           'AveragedDQN', 'CategoricalDQN', 'DuelingDQN', 'NoisyDQN', 'MaxminDQN', 'Rainbow',
-           'QLearning', 'QLambda', 'DoubleQLearning', 'WeightedQLearning',
+           'AveragedDQN', 'CategoricalDQN', 'DuelingDQN', 'NoisyDQN', 'QuantileDQN',
+           'MaxminDQN', 'Rainbow', 'QLearning', 'QLambda', 'DoubleQLearning', 'WeightedQLearning',
            'MaxminQLearning', 'SpeedyQLearning', 'RLearning', 'RQLearning',
            'SARSA', 'SARSALambda', 'SARSALambdaContinuous', 'ExpectedSARSA',
            'TrueOnlineSARSALambda']
