@@ -16,7 +16,11 @@ class DoubleQLearning(TD):
 
         super().__init__(mdp_info, policy, Q, learning_rate)
 
-        self.alpha = [deepcopy(self.alpha), deepcopy(self.alpha)]
+        self._alpha_double = [deepcopy(self._alpha), deepcopy(self._alpha)]
+
+        self._add_save_attr(
+            _alpha_double='primitive'
+        )
 
         assert len(self.Q) == 2, 'The regressor ensemble must' \
                                  ' have exactly 2 models.'
@@ -35,7 +39,7 @@ class DoubleQLearning(TD):
         else:
             q_next = 0.
 
-        q = q_current + self.alpha[approximator_idx](state, action) * (
+        q = q_current + self._alpha_double[approximator_idx](state, action) * (
             reward + self.mdp_info.gamma * q_next - q_current)
 
         self.Q[approximator_idx][state, action] = q
