@@ -34,9 +34,9 @@ class TorchApproximator(Serializable):
                 method of the network;
             use_cuda (bool, False): if True, runs the network on the GPU;
             reinitialize (bool, False): if True, the approximator is re
-            initialized at every fit call. To perform the initialization, the
-            weights_init method must be defined properly for the selected
-            model network.
+                initialized at every fit call. To perform the initialization, 
+                the weights_init method must be defined properly for the 
+                selected model network.
             dropout (bool, False): if True, dropout is applied only during
                 train;
             quiet (bool, True): if False, shows two progress bars, one for
@@ -98,7 +98,7 @@ class TorchApproximator(Serializable):
         if not self._use_cuda:
             torch_args = [torch.from_numpy(x) if isinstance(x, np.ndarray) else x
                           for x in args]
-            val = self.network.forward(*torch_args, **kwargs)
+            val = self.network(*torch_args, **kwargs)
 
             if output_tensor:
                 return val
@@ -109,8 +109,7 @@ class TorchApproximator(Serializable):
         else:
             torch_args = [torch.from_numpy(x).cuda()
                           if isinstance(x, np.ndarray) else x.cuda() for x in args]
-            val = self.network.forward(*torch_args,
-                                       **kwargs)
+            val = self.network(*torch_args, **kwargs)
 
             if output_tensor:
                 return val
@@ -259,7 +258,7 @@ class TorchApproximator(Serializable):
         else:
             output_type = y_hat.dtype
 
-        y = [y_i.clone().detach().requires_grad_(False).type(output_type) for y_i
+        y = [y_i.clone().detach().type(output_type) for y_i
              in torch_args[-self._n_fit_targets:]]
 
         if self._use_cuda:
@@ -351,6 +350,11 @@ class TorchApproximator(Serializable):
 
     @property
     def loss_fit(self):
+        """
+        Returns:
+            The average loss of the last epoch of the last fit call.
+            
+        """
         return self._last_loss
 
     def _post_load(self):
