@@ -1,93 +1,95 @@
-import mujoco_py
-from mujoco_py import functions as mj_fun
+import mujoco
 import numpy as np
-from enum import Enum
 from mushroom_rl.core import Environment, MDPInfo
 from mushroom_rl.utils.spaces import Box
-import glfw
-
-
-class ObservationType(Enum):
-    """
-    An enum indicating the type of data that should be added to the observation
-    of the environment, can be Joint-/Body-/Site- positions and velocities.
-
-    """
-    __order__ = "BODY_POS BODY_VEL JOINT_POS JOINT_VEL SITE_POS SITE_VEL"
-    BODY_POS = 0
-    BODY_VEL = 1
-    JOINT_POS = 2
-    JOINT_VEL = 3
-    SITE_POS = 4
-    SITE_VEL = 5
+from mushroom_rl.utils.mujoco import *
 
 
 class MuJoCo(Environment):
     """
     Class to create a Mushroom environment using the MuJoCo simulator.
-
     """
-    def __init__(self, file_name, actuation_spec, observation_spec, gamma,
-                 horizon, n_substeps=1, n_intermediate_steps=1, additional_data_spec=None,
-                 collision_groups=None):
+
+    def __init__(self, file_name, actuation_spec, observation_spec, gamma, horizon, timestep=None, n_substeps=1,
+                 n_intermediate_steps=1, additional_data_spec=None, collision_groups=None, max_joint_vel=None,
+                 **viewer_params):
         """
         Constructor.
 
         Args:
-            file_name (string): The path to the XML file with which the
+             file_name (string): The path to the XML file with which the
                 environment should be created;
-            actuation_spec (list): A list specifying the names of the joints
+             actuation_spec (list): A list specifying the names of the joints
                 which should be controllable by the agent. Can be left empty
                 when all actuators should be used;
-            observation_spec (list): A list containing the names of data that
+             observation_spec (list): A list containing the names of data that
                 should be made available to the agent as an observation and
-                their type (ObservationType). An entry in the list is given by:
-                (name, type);
-            gamma (float): The discounting factor of the environment;
-            horizon (int): The maximum horizon for the environment;
-            n_substeps (int): The number of substeps to use by the MuJoCo
+                their type (ObservationType). They are combined with a key,
+                which is used to access the data. An entry in the list
+                is given by: (key, name, type). The name can later be used
+                to retrieve specific observations;
+             gamma (float): The discounting factor of the environment;
+             horizon (int): The maximum horizon for the environment;
+             timestep (float): The timestep used by the MuJoCo
+                simulator. If None, the default timestep specified in the XML will be used;
+             n_substeps (int, 1): The number of substeps to use by the MuJoCo
                 simulator. An action given by the agent will be applied for
                 n_substeps before the agent receives the next observation and
                 can act accordingly;
-            n_intermediate_steps (int): The number of steps between every action
+             n_intermediate_steps (int, 1): The number of steps between every action
                 taken by the agent. Similar to n_substeps but allows the user
                 to modify, control and access intermediate states.
-            additional_data_spec (list): A list containing the data fields of
+             additional_data_spec (list, None): A list containing the data fields of
                 interest, which should be read from or written to during
                 simulation. The entries are given as the following tuples:
                 (key, name, type) key is a string for later referencing in the
                 "read_data" and "write_data" methods. The name is the name of
                 the object in the XML specification and the type is the
                 ObservationType;
-            collision_groups (list): A list containing groups of geoms for
+             collision_groups (list, None): A list containing groups of geoms for
                 which collisions should be checked during simulation via
                 ``check_collision``. The entries are given as:
                 ``(key, geom_names)``, where key is a string for later
                 referencing in the "check_collision" method, and geom_names is
                 a list of geom names in the XML specification.
+             max_joint_vel (list, None): A list with the maximum joint velocities which are provided in the mdp_info.
+                The list has to define a maximum velocity for every occurrence of JOINT_VEL in the observation_spec. The
+                velocity will not be limited in mujoco
+             **viewer_params: other parameters to be passed to the viewer.
+                See MujocoGlfwViewer documentation for the available options.
+
         """
         # Create the simulation
-        self._sim = self._load_simulation(file_name, n_substeps)
+        self._model = mujoco.MjModel.from_xml_path(file_name)
+        if timestep is not None:
+            self._model.opt.timestep = timestep
+            self._timestep = timestep
+        else:
+            self._timestep = self._model.opt.timestep
+
+        self._data = mujoco.MjData(self._model)
 
         self._n_intermediate_steps = n_intermediate_steps
+        self._n_substeps = n_substeps
+        self._viewer_params = viewer_params
         self._viewer = None
-        self._state = None
+        self._obs = None
 
         # Read the actuation spec and build the mapping between actions and ids
         # as well as their limits
         if len(actuation_spec) == 0:
-            self._action_indices = [i for i in range(0, len(self._sim.model._actuator_name2id))]
+            self._action_indices = [i for i in range(0, len(self._data.actuator_force))]
         else:
             self._action_indices = []
             for name in actuation_spec:
-                self._action_indices.append(self._sim.model._actuator_name2id[name])
+                self._action_indices.append(self._model.actuator(name).id)
 
         low = []
         high = []
         for index in self._action_indices:
-            if self._sim.model.actuator_ctrllimited[index]:
-                low.append(self._sim.model.actuator_ctrlrange[index][0])
-                high.append(self._sim.model.actuator_ctrlrange[index][1])
+            if self._model.actuator_ctrllimited[index]:
+                low.append(self._model.actuator_ctrlrange[index][0])
+                high.append(self._model.actuator_ctrlrange[index][1])
             else:
                 low.append(-np.inf)
                 high.append(np.inf)
@@ -95,30 +97,9 @@ class MuJoCo(Environment):
 
         # Read the observation spec to build a mapping at every step. It is
         # ensured that the values appear in the order they are specified.
-        if len(observation_spec) == 0:
-            raise AttributeError("No Environment observations were specified. "
-                                 "Add at least one observation to the observation_spec.")
-        else:
-            self._observation_map = observation_spec
+        self.obs_helper = ObservationHelper(observation_spec, self._model, self._data, max_joint_velocity=max_joint_vel)
 
-        # We can only specify limits for the joint positions, all other
-        # information can be potentially unbounded
-        low = []
-        high = []
-        for name, ot in self._observation_map:
-            obs_count = len(self._get_observation(name, ot))
-            if obs_count == 1 and ot == ObservationType.JOINT_POS:
-                joint_range = self._sim.model.jnt_range[self._sim.model._joint_name2id[name]]
-                if not(joint_range[0] == joint_range[1] == 0.0):
-                    low.append(joint_range[0])
-                    high.append(joint_range[1])
-                else:
-                    low.append(-np.inf)
-                    high.append(np.inf)
-            else:
-                low.extend([-np.inf] * obs_count)
-                high.extend([np.inf] * obs_count)
-        observation_space = Box(np.array(low), np.array(high))
+        observation_space = Box(*self.obs_helper.get_obs_limits())
 
         # Pre-process the additional data to allow easier writing and reading
         # to and from arrays in MuJoCo
@@ -131,26 +112,32 @@ class MuJoCo(Environment):
         self.collision_groups = {}
         if collision_groups is not None:
             for name, geom_names in collision_groups:
-                self.collision_groups[name] = {self._sim.model._geom_name2id[geom_name]
+                self.collision_groups[name] = {mujoco.mj_name2id(self._model, mujoco.mjtObj.mjOBJ_GEOM, geom_name)
                                                for geom_name in geom_names}
 
         # Finally, we create the MDP information and call the constructor of
         # the parent class
         mdp_info = MDPInfo(observation_space, action_space, gamma, horizon)
+
+        mdp_info = self._modify_mdp_info(mdp_info)
+
+        # set the warning callback to stop the simulation when a mujoco warning occurs
+        mujoco.set_mju_user_warning(self.user_warning_raise_exception)
+
         super().__init__(mdp_info)
 
     def seed(self, seed):
         np.random.seed(seed)
 
-    def reset(self, state=None):
-        mj_fun.mj_resetData(self._sim.model, self._sim.data)
-        self._setup()
+    def reset(self, obs=None):
+        mujoco.mj_resetData(self._model, self._data)
+        self.setup()
 
-        self._state = self._create_observation()
-        return self._state
+        self._obs = self._create_observation(self.obs_helper.build_obs(self._data))
+        return self._modify_observation(self._obs)
 
     def step(self, action):
-        cur_obs = self._state
+        cur_obs = self._obs.copy()
 
         action = self._preprocess_action(action)
 
@@ -158,61 +145,94 @@ class MuJoCo(Environment):
 
         for i in range(self._n_intermediate_steps):
 
-            ctrl_action = self._compute_action(action)
-            self._sim.data.ctrl[self._action_indices] = ctrl_action
+            ctrl_action = self._compute_action(cur_obs, action)
+            self._data.ctrl[self._action_indices] = ctrl_action
 
             self._simulation_pre_step()
 
-            self._sim.step()
+            mujoco.mj_step(self._model, self._data, self._n_substeps)
 
             self._simulation_post_step()
 
-        self._state = self._create_observation()
+            cur_obs = self._create_observation(self.obs_helper.build_obs(self._data))
 
         self._step_finalize()
 
-        reward = self._reward(cur_obs, action, self._state)
+        absorbing = self.is_absorbing(cur_obs)
+        reward = self.reward(self._obs, action, cur_obs, absorbing)
+        info = self._create_info_dictionary(cur_obs)
 
-        return self._state, reward, self._is_absorbing(self._state), {}
+        self._obs = cur_obs
+
+        return self._modify_observation(cur_obs), reward, absorbing, info
 
     def render(self):
         if self._viewer is None:
-            self._viewer = mujoco_py.MjViewer(self._sim)
+            self._viewer = MujocoGlfwViewer(self._model, self.dt, **self._viewer_params)
 
-        self._viewer.render()
+        self._viewer.render(self._data)
 
     def stop(self):
         if self._viewer is not None:
-            v = self._viewer
+            self._viewer.stop()
+            del self._viewer
             self._viewer = None
-            glfw.destroy_window(v.window)
-            del v
 
-    def _get_observation(self, name, otype):
-        if otype == ObservationType.BODY_POS:
-            data = self._sim.data.get_body_xpos(name)
-        elif otype == ObservationType.BODY_VEL:
-            data = self._sim.data.get_body_xvelp(name)
-        elif otype == ObservationType.JOINT_POS:
-            data = self._sim.data.get_joint_qpos(name)
-        elif otype == ObservationType.JOINT_VEL:
-            data = self._sim.data.get_joint_qvel(name)
-        elif otype == ObservationType.SITE_POS:
-            data = self._sim.data.get_site_xpos(name)
-        elif otype == ObservationType.SITE_VEL:
-            data = self._sim.data.get_site_xvelp(name)
-        else:
-            raise ValueError('Invalid observation type')
+    def _modify_mdp_info(self, mdp_info):
+        """
+        This method can be overridden to modify the automatically generated MDPInfo data structure.
+        By default, returns the given mdp_info structure unchanged.
 
-        if hasattr(data, "__len__"):
-            return data
-        else:
-            return [data]
+        Args:
+            mdp_info (MDPInfo): the MDPInfo structure automatically computed by the environment.
 
-    def _create_observation(self):
-        data_obs = [self._get_observation(name, ot)
-                    for name, ot in self._observation_map]
-        return np.concatenate(data_obs)
+        Returns:
+            The modified MDPInfo data structure.
+
+        """
+        return mdp_info
+
+    def _create_observation(self, obs):
+        """
+        This method can be overridden to create a custom observation. Should be used to append observation which have
+        been registered via obs_help.add_obs(self, name, o_type, length, min_value, max_value)
+
+        Args:
+            obs (np.ndarray): the generated observation
+
+        Returns:
+            The environment observation.
+
+        """
+        return obs
+
+    def _create_info_dictionary(self, obs):
+        """
+        This method can be overridden to create a custom info dictionary.
+
+        Args:
+            obs (np.ndarray): the generated observation
+
+        Returns:
+            The information dictionary.
+
+        """
+        return {}
+
+    def _modify_observation(self, obs):
+        """
+        This method can be overridden to edit the created observation. This is done after the reward and absorbing
+        functions are evaluated. Especially useful to transform the observation into different frames. If the original
+        observation order is not preserved, the helper functions in ObervationHelper breaks.
+
+        Args:
+            obs (np.ndarray): the generated observation
+
+        Returns:
+            The environment observation.
+
+        """
+        return obs
 
     def _preprocess_action(self, action):
         """
@@ -228,23 +248,24 @@ class MuJoCo(Environment):
         """
         return action
 
-    def _step_init(self, state, action):
+    def _step_init(self, obs, action):
         """
         Allows information to be initialized at the start of a step.
+
         """
         pass
 
-    def _compute_action(self, action):
+    def _compute_action(self, obs, action):
         """
         Compute a transformation of the action at every intermediate step.
         Useful to add control signals simulated directly in python.
 
         Args:
-            action (np.ndarray): numpy array with the actions
-                provided at every step.
+            obs (np.ndarray): numpy array with the current state of teh simulation;
+            action (np.ndarray): numpy array with the actions, provided at every step.
 
         Returns:
-            The action to be set in the actual mujoco simulation.
+            The action to be set in the actual pybullet simulation.
 
         """
         return action
@@ -252,21 +273,23 @@ class MuJoCo(Environment):
     def _simulation_pre_step(self):
         """
         Allows information to be accesed and changed at every intermediate step
-            before taking a step in the mujoco simulation.
-            Can be usefull to apply an external force/torque to the specified bodies.
+        before taking a step in the mujoco simulation.
+        Can be usefull to apply an external force/torque to the specified bodies.
 
         ex: apply a force over X to the torso:
-            force = [200, 0, 0]
-            torque = [0, 0, 0]
-            self.sim.data.xfrc_applied[self.sim.model._body_name2id["torso"],:] = force + torque
+        force = [200, 0, 0]
+        torque = [0, 0, 0]
+        self.sim.data.xfrc_applied[self.sim.model._body_name2id["torso"],:] = force + torque
+
         """
         pass
 
     def _simulation_post_step(self):
         """
         Allows information to be accesed at every intermediate step
-            after taking a step in the mujoco simulation.
-            Can be usefull to average forces over all intermediate steps.
+        after taking a step in the mujoco simulation.
+        Can be usefull to average forces over all intermediate steps.
+
         """
         pass
 
@@ -289,7 +312,7 @@ class MuJoCo(Environment):
 
         """
         data_id, otype = self.additional_data[name]
-        return np.array(self._get_observation(data_id, otype))
+        return np.array(self.obs_helper.get_state(self._data, data_id, otype))
 
     def _write_data(self, name, value):
         """
@@ -303,13 +326,12 @@ class MuJoCo(Environment):
         """
 
         data_id, otype = self.additional_data[name]
-
         if otype == ObservationType.JOINT_POS:
-            self._sim.data.set_joint_qpos(data_id, value)
+            self._data.joint(data_id).qpos = value
         elif otype == ObservationType.JOINT_VEL:
-            self._sim.data.set_joint_qvel(data_id, value)
+            self._data.joint(data_id).qvel = value
         else:
-            data_buffer = self._get_observation(data_id, otype)
+            data_buffer = self.obs_helper.get_state(self._data, data_id, otype)
             data_buffer[:] = value
 
     def _check_collision(self, group1, group2):
@@ -327,17 +349,19 @@ class MuJoCo(Environment):
             groups or not.
 
         """
+
         ids1 = self.collision_groups[group1]
         ids2 = self.collision_groups[group2]
 
-        for coni in range(0, self._sim.data.ncon):
-            con = self._sim.data.contact[coni]
+        for coni in range(0, self._data.ncon):
+            con = self._data.contact[coni]
 
             collision = con.geom1 in ids1 and con.geom2 in ids2
             collision_trans = con.geom1 in ids2 and con.geom2 in ids1
 
             if collision or collision_trans:
                 return True
+
         return False
 
     def _get_collision_force(self, group1, group2):
@@ -356,31 +380,33 @@ class MuJoCo(Environment):
             http://mujoco.org/book/programming.html#siContact
 
         """
+
         ids1 = self.collision_groups[group1]
         ids2 = self.collision_groups[group2]
 
         c_array = np.zeros(6, dtype=np.float64)
-        for con_i in range(0, self._sim.data.ncon):
-            con = self._sim.data.contact[con_i]
+        for con_i in range(0, self._data.ncon):
+            con = self._data.contact[con_i]
 
             if (con.geom1 in ids1 and con.geom2 in ids2 or
                con.geom1 in ids2 and con.geom2 in ids1):
 
-                mujoco_py.functions.mj_contactForce(self._sim.model, self._sim.data,
-                                                    con_i, c_array)
+                mujoco.mj_contactForce(self._model, self._data,
+                                       con_i, c_array)
                 return c_array
 
         return c_array
 
-    def _reward(self, state, action, next_state):
+    def reward(self, obs, action, next_obs, absorbing):
         """
         Compute the reward based on the given transition.
 
         Args:
-            state (np.array): the current state of the system;
+            obs (np.array): the current state of the system;
             action (np.array): the action that is applied in the current state;
-            next_state (np.array): the state reached after applying the given
+            next_obs (np.array): the state reached after applying the given
                 action.
+            absorbing (bool): whether next_state is an absorbing state or not.
 
         Returns:
             The reward as a floating point scalar value.
@@ -388,12 +414,12 @@ class MuJoCo(Environment):
         """
         raise NotImplementedError
 
-    def _is_absorbing(self, state):
+    def is_absorbing(self, obs):
         """
         Check whether the given state is an absorbing state or not.
 
         Args:
-            state (np.array): the state of the system.
+            obs (np.array): the state of the system.
 
         Returns:
             A boolean flag indicating whether this state is absorbing or not.
@@ -401,7 +427,7 @@ class MuJoCo(Environment):
         """
         raise NotImplementedError
 
-    def _setup(self):
+    def setup(self):
         """
         A function that allows to execute setup code after an environment
         reset.
@@ -409,25 +435,34 @@ class MuJoCo(Environment):
         """
         pass
 
-    def _load_simulation(self, file_name, n_substeps):
+    def get_all_observation_keys(self):
         """
-        Load mujoco model. Can be overridden to provide custom load functions.
-
-        Args:
-             file_name (string): The path to the XML file with which the
-                environment should be created;
-            n_substeps (int): The number of substeps to use by the MuJoCo
-                simulator. An action given by the agent will be applied for
-                n_substeps before the agent receives the next observation and
-                can act accordingly.
+        A function that returns all observation keys defined in the observation specification.
 
         Returns:
-            The loaded mujoco model.
+            A list of observation keys.
 
         """
-        return mujoco_py.MjSim(mujoco_py.load_model_from_path(file_name),
-                               nsubsteps=n_substeps)
+        return self.obs_helper.get_all_observation_keys()
 
     @property
-    def _dt(self):
-        return self._sim.model.opt.timestep
+    def dt(self):
+        return self._timestep * self._n_intermediate_steps * self._n_substeps
+
+    @staticmethod
+    def user_warning_raise_exception(warning):
+        """
+        Detects warnings in Mujoco and raises the respective exception.
+
+        Args:
+            warning: Mujoco warning.
+
+        """
+        if 'Pre-allocated constraint buffer is full' in warning:
+            raise RuntimeError(warning + 'Increase njmax in mujoco XML')
+        elif 'Pre-allocated contact buffer is full' in warning:
+            raise RuntimeError(warning + 'Increase njconmax in mujoco XML')
+        elif 'Unknown warning type' in warning:
+            raise RuntimeError(warning + 'Check for NaN in simulation.')
+        else:
+            raise RuntimeError('Got MuJoCo Warning: ' + warning)
