@@ -20,26 +20,28 @@ class DeterministicPolicy(ParametricPolicy):
 
         """
         self._approximator = mu
+        self._predict_params = dict()
 
         self._add_save_attr(_approximator='mushroom')
+        self._add_save_attr(_predict_params='pickle')
 
     def get_regressor(self):
         """
         Getter.
 
         Returns:
-            the regressor that is used to map state to actions.
+            The regressor that is used to map state to actions.
 
         """
         return self._approximator
 
     def __call__(self, state, action):
-        policy_action = self._approximator.predict(state)
+        policy_action = self._approximator.predict(state, **self._predict_params)
 
         return 1. if np.array_equal(action, policy_action) else 0.
 
     def draw_action(self, state):
-        return self._approximator.predict(state)
+        return self._approximator.predict(state, **self._predict_params)
 
     def set_weights(self, weights):
         self._approximator.set_weights(weights)
